@@ -1,13 +1,17 @@
-from contextlib import contextmanager
-import time
+from __future__ import annotations
+
 import datetime
 import os
+import time
+import typing
+import zoneinfo
+from contextlib import contextmanager
+
 import pytest
-from dateutil import tz
 
 
 @contextmanager
-def stub_timezone_ctx(tzname):
+def stub_timezone_ctx(tzname: str | None) -> typing.Generator[None]:
     """
     Switch to a locally-known timezone specified by `tzname`.
     On exit, restore the previous timezone.
@@ -21,16 +25,16 @@ def stub_timezone_ctx(tzname):
     if not hasattr(time, "tzset"):
         pytest.skip("Timezone patching is not supported")
 
-    # Make sure the new timezone exists, at least in dateutil
-    new_tz = tz.gettz(tzname)
-    if new_tz is None:
-        raise ValueError("Invalid timezone specified: %r" % (tzname,))
+    # Make sure the new timezone exists
+    try:
+        zoneinfo.ZoneInfo(tzname)
+    except zoneinfo.ZoneInfoNotFoundError:
+        raise ValueError(f"Invalid timezone specified: {tzname!r}")
 
     # Get the current timezone
-    local_tz = tz.tzlocal()
-    if local_tz is None:
-        raise EnvironmentError("Cannot determine current timezone")
-    old_tzname = datetime.datetime.now(local_tz).tzname()
+    old_tzname = datetime.datetime.now().astimezone().tzname()
+    if old_tzname is None:
+        raise OSError("Cannot determine current timezone")
 
     os.environ["TZ"] = tzname
     time.tzset()
